ANSWER_TIMEOUT = 300  # 300 sec. timeout to answer in dialog

FOREWORD = "Для прохождения опроста, пожалуйста напишите /start"

CANCEL = "Опрос отменён! Если Вы передумаете в будущем, то начните опрос заново, используя команду /start."

WRONG_ANSWER_FORMAT = "Некорректный формат ответа!"

SESSION_DOESNT_EXIST = "Вы не проходили опрос, поэтому нечего останавливать"
